import * as React from 'react';
import { IWavesConsoleAPIHelpCommand } from '../../WavesConsoleAPI';
/**
 * @interface {IInputProps}
 */
export interface IInputProps {
    inputRef: any;
    onRun: any;
    autoFocus: any;
    onClear: any;
    theme: string;
    history: Array<string>;
    addHistory: any;
    value?: string;
}
/**
 * @interface {IInputState}
 */
export interface IInputState {
    value: string;
    multiline: boolean;
    rows: number;
    historyCursor: number;
    hideSuggest: boolean;
}
/**
 * @interface {ISuggestRootProps}
 */
export interface ISuggestRootProps {
    value?: string;
    commands?: string[];
    dropdown?: boolean;
    theme?: string;
}
/**
 * @interface {ISuggestItemProps}
 */
export interface ISuggestItemProps {
    title: string;
    selected?: boolean;
}
/**
 * @class {Input}
 * @extends {React.Component}
 */
export declare class Input extends React.Component<IInputProps, IInputState> {
    /**
     * @private
     * @member {HTMLTextAreaElement?} input
     */
    private input?;
    /**
     * @static
     * @member {object} commandsVocabulary
     */
    static commandsVocabulary: {
        [key: string]: IWavesConsoleAPIHelpCommand;
    };
    /**
     * @static
     * @member {Array} commandsList
     */
    static commandsList: Array<string>;
    /**
     * @static
     * @member {object} commasAndQuotes
     */
    static commasAndQuotes: {
        [key: string]: string;
    };
    /**
     * @constructor
     *
     * @param {IInputProps} props
     */
    constructor(props: IInputProps);
    /**
     * @method {onChange}
     *
     * @returns {undefined}
     */
    onChange(): void;
    /**
     * @async
     * @method {onKeyPress}
     *
     * @param {React.KeyboardEvent} event
     *
     * @returns {Promise}
     */
    onKeyPress(event: React.KeyboardEvent): Promise<void>;
    /**
     * @method {checkClearAction}
     *
     * @param {React.KeyboardEvent} event
     * @param {string} code
     *
     * @returns {boolean}
     */
    checkClearAction(event: React.KeyboardEvent, code: string): boolean;
    /**
     * @method {checkShowSuggestAction}
     *
     * @param {React.KeyboardEvent} event
     * @param {string} code
     */
    checkShowSuggestAction(event: React.KeyboardEvent, code: string): boolean;
    /**
     * @method {checkHideSuggestAction}
     *
     * @param {React.KeyboardEvent} event
     * @param {string} code
     *
     * @returns {boolean}
     */
    checkHideSuggestAction(event: React.KeyboardEvent, code: string): boolean;
    /**
     * @method {checkAutoclosingAction}
     *
     * @param {React.KeyboardEvent} event
     */
    checkAutoclosingAction(event: React.KeyboardEvent): void;
    /**
     * @method {checkNotMultilineActions}
     *
     * @param {React.KeyboardEvent} event
     * @param {string} code
     *
     * @returns {boolean}
     */
    checkNotMultilineActions(event: React.KeyboardEvent, code: string): boolean;
    /**
     * Get entry for search from full input.value string
     *
     * @method {getCurrentCommandPiece}
     *
     * @returns {string}
     */
    getCurrentCommandPiece(): string | undefined;
    /**
     * Set closing bracket of given type
     *
     * @method {setClosingBracketOrQuoteIntoInput}
     *
     * @param {string} open
     */
    setClosingBracketOrQuoteIntoInput(open?: string): void;
    /**
     * Set closing bracket of given type
     *
     * @method {unsetClosingBracketOrQuoteIntoInput}
     */
    unsetClosingBracketOrQuoteIntoInput(): void;
    /**
     * Set command into input using found autocomplition variants
     *
     * @method {setCommandIntoInput}
     */
    setCommandIntoInput(): void;
    /**
     * Get list of commands filtered with needed command piece
     *
     * @method {getFilteredCommandsList}
     *
     * @returns {Array}
     */
    getFilteredCommandsList(): Array<string>;
    /**
     * @method {render}
     *
     * @returns {React.Element}
     */
    render(): JSX.Element;
    /**
     * @method {createSuggest}
     *
     * @returns {React.Element}
     */
    createSuggest(dropdown: boolean): JSX.Element;
    /**
     * @method {createTextarea}
     *
     * @returns {React.Element}
     */
    createTextarea(): JSX.Element;
}
